# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import winrt.system
from winrt import _winrt_windows_media_capture_core

__all__ = [
    "VariablePhotoCapturedEventArgs",
    "VariablePhotoSequenceCapture",
]

VariablePhotoCapturedEventArgs = _winrt_windows_media_capture_core.VariablePhotoCapturedEventArgs
VariablePhotoSequenceCapture = _winrt_windows_media_capture_core.VariablePhotoSequenceCapture
